==> haskell-ordered-containers-0.2.4-99.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ordered-containers
version:              0.2.4
visibility:           public
id:                   ordered-containers-0.2.4-EwHJBRsxryDGW0prEJhSCp
key:                  ordered-containers-0.2.4-EwHJBRsxryDGW0prEJhSCp
license:              BSD-3-Clause
maintainer:           me@dmwit.com
author:               Daniel Wagner
synopsis:
    Set- and Map-like types that remember the order elements were inserted

category:             Data
abi:                  2e1f9ce192595cc00a252ec1eefffa03
exposed:              True
exposed-modules:
    Data.Map.Ordered Data.Map.Ordered.Strict Data.Set.Ordered

hidden-modules:       Data.Map.Ordered.Internal Data.Map.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ordered-containers-0.2.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ordered-containers-0.2.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ordered-containers-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ordered-containers
hs-libraries:         HSordered-containers-0.2.4-EwHJBRsxryDGW0prEJhSCp
depends:
    base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z

haddock-interfaces:
    /usr/share/doc/haskell-ordered-containers/html/ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ordered-containers-0.2.4-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ordered-containers
version:              0.2.4
visibility:           public
id:                   ordered-containers-0.2.4-7LS72pannWi66bkfz7GPiT
key:                  ordered-containers-0.2.4-7LS72pannWi66bkfz7GPiT
license:              BSD-3-Clause
maintainer:           me@dmwit.com
author:               Daniel Wagner
synopsis:
    Set- and Map-like types that remember the order elements were inserted

category:             Data
abi:                  4210e8f5561fa4f974c2215c1d0f0b1d
exposed:              True
exposed-modules:
    Data.Map.Ordered Data.Map.Ordered.Strict Data.Set.Ordered

hidden-modules:       Data.Map.Ordered.Internal Data.Map.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ordered-containers-0.2.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ordered-containers-0.2.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ordered-containers-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ordered-containers
hs-libraries:         HSordered-containers-0.2.4-7LS72pannWi66bkfz7GPiT
depends:
    base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD

haddock-interfaces:
    /usr/share/doc/haskell-ordered-containers/html/ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
